#!/bin/sh

# detect loaded camera driver
init_dev() {
	CAMERA=""
	CAMERA=`media-ctl -p | grep '^- entity 16:' | awk '{print $4}'`

	case $CAMERA in
		mt9v022)
			CAMERA="mt9v02x";;
		mt9m001)
			CAMERA=$CAMERA;;
		mt9m111)
			CAMERA=$CAMERA;;
		mt9p031)
			CAMERA="mt9p031_mt9p006";;
		tw9910)
			CAMERA=$CAMERA;;
		*)
			continue;;
	esac

	if [ -n $CAMERA ]; then
		echo "Camera $CAMERA attached."
		return 0
    fi

	echo "Unable to load camera driver, exit."                            
	return 1
}


guess_param() {
	CAM_DEVICE="/dev/v4l-subdev8"
	COL_FORMAT=SBGGR8 
	COL_FORMAT_1=SGBRG8
	COL_FORMAT_2=SGBRG10
	COL_FORMAT_3=UYVY
	BW_FORMAT=Y8
	BW_FORMAT_1=Y8
	BW_FORMAT_2=Y10
	FRAME_SIZE='752x480'
	FRAME_SIZE_32BYTE_ALIGNED='736x480'
	FRAME_SIZE_OUT_CCDC='752x479'
	FRAME_SIZE_OUT_PREVIEW='738x471'
	OFFSET_SENSOR='0,0'
	REG_SET_FILE='register-settings-mt9v02x.txt'
	NUMBER_OF_PIC='2'
	NORM=''
	FRAME_RAW_COL_OUT='RAW, SBGGR8, 736x480'
	FRAME_RAW_BW_OUT='RAW, Y8, 736x480'
	
	case $CAMERA in
      mt9v02x)
        FRAME_SIZE='752x480' && \	
        FRAME_SIZE_32BYTE_ALIGNED='736x480' && \
		FRAME_SIZE_OUT_CCDC='752x479' && FRAME_SIZE_OUT_PREVIEW='738x471' && \
        COL_FORMAT=SGBRG8 && COL_FORMAT_1=SGBRG8 && \
        COL_FORMAT_2=SGBRG10 && COL_FORMAT_3=UYVY && \
        BW_FORMAT=Y8 && BW_FORMAT_1=Y8 && BW_FORMAT_2=Y10 && \
        REG_SET_FILE="$(dirname $0)/register-settings-mt9v02x.txt" && \
        NUMBER_OF_PIC='2' && \
        FRAME_RAW_COL_OUT='RAW, SGBRG8, 736x480' && \
        FRAME_RAW_BW_OUT='RAW, Y8, 736x480'
	;;
      mt9m001)
        FRAME_SIZE='1280x1024' && \
		FRAME_SIZE_32BYTE_ALIGNED=$FRAME_SIZE && \
		BW_FORMAT=Y8 && BW_FORMAT_1=Y8 && BW_FORMAT_2=Y10 && \
		REG_SET_FILE="$(dirname $0)/register-settings-mt9m001.txt" && \
		NUMBER_OF_PIC='2' && \
		FRAME_RAW_BW_OUT='RAW, Y8, 1280x1024'
	;;
      mt9m111) 
        FRAME_SIZE='1280x1024' && OFFSET_SENSOR='30,12' && \
		FRAME_SIZE_32BYTE_ALIGNED=$FRAME_SIZE && \
		COL_FORMAT=YUYV2X8 && COL_FORMAT_1=$COL_FORMAT && COL_FORMAT_2=$COL_FORMAT && \
		REG_SET_FILE="$(dirname $0)/register-settings-mt9m131.txt" && \
		NUMBER_OF_PIC='6' && \
		FRAME_RAW_COL_OUT='RAW, YUYV, 1280x1024'
	;;
      tw9910)
	    FRAME_SIZE='768x288' &&  OFFSET_SENSOR='0,0' && \
	    FRAME_SIZE_32BYTE_ALIGNED='768x288' && \
	    COL_FORMAT=UYVY2X8 && COL_FORMAT_1=$COL_FORMAT && COL_FORMAT_2=$COL_FORMAT && \
	    REG_SET_FILE="$(dirname $0)/register-settings-tw9910.txt" && \
	    NUMBER_OF_PIC="4" && NORM="norm=PAL" && \
	    FRAME_RAW_COL_OUT='RAW, UYVY, half frame 768x288'
	;;
	  mt9p031_mt9p006)
        FRAME_SIZE='2592x1944' && OFFSET_SENSOR='16,54' && \
        FRAME_SIZE_32BYTE_ALIGNED='2592x1944' && \
		FRAME_SIZE_OUT_CCDC='2592x1943' && FRAME_SIZE_OUT_PREVIEW='2576x1935' && \
        COL_FORMAT=SGRBG12 && COL_FORMAT_1=SGRBG8 && \
        COL_FORMAT_2=SGRBG10 && COL_FORMAT_3=YUYV && \
        BW_FORMAT=Y12 && BW_FORMAT_1=Y8 && BW_FORMAT_2=Y10 && \
        REG_SET_FILE="$(dirname $0)/register-settings-mt9p031.txt" && \
        NUMBER_OF_PIC='2' && \
        FRAME_RAW_COL_OUT='RAW, SBGGR8, 2592x1944' && \
        FRAME_RAW_BW_OUT='RAW, Y8, 2592x1944'
	;;
    esac
		
}
